@@ -1,4 +1,5 @@
 from django.core.management.base import BaseCommand
+from django.db import DEFAULT_DB_ALIAS
 
 from django_pgviews.models import ViewRefresher
 
@@ -14,6 +15,11 @@ class Command(BaseCommand):
             dest="concurrently",
             help="Refresh concurrently if the materialized view supports it",
         )
+        parser.add_argument(
+            "--database",
+            default=DEFAULT_DB_ALIAS,
+            help='Nominates a database to synchronize. Defaults to the "default" database.',
+        )
 
-    def handle(self, concurrently, **options):
-        ViewRefresher().run(concurrently)
+    def handle(self, concurrently, database, **options):
+        ViewRefresher().run(concurrently, using=database)
